/*
 * Copyright (C) 2004 Mike Hearn, for CodeWeavers
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * This program is a general purpose bridge between the Windows
 * environment and native. Currently it deals with system tray
 * windows, in future it may take on other functions that the standard
 * windows shell (Explorer) deals with, for instance responding to DDE
 * requests and syncing the wallpaper with native.
 */

#include <stdio.h>
#include <assert.h>

#include <windows.h>
#include <wine/debug.h>

#include <systray.h>

WINE_DEFAULT_DEBUG_CHANNEL(explorer);

unsigned int shell_refs = 0;

int main(int argc, char *argv[])
{
    initialize_systray();

    while (TRUE)
    {
        const int timeout = 5;
        MSG message;
        DWORD res;

        res = MsgWaitForMultipleObjectsEx(0, NULL, shell_refs ? INFINITE : timeout * 1000,
                                          QS_ALLINPUT, MWMO_WAITALL);
        if (res == WAIT_TIMEOUT) break;

        res = PeekMessage(&message, 0, 0, 0, PM_REMOVE);
        if (!res) continue;

        if (message.message == WM_QUIT)
        {
            WINE_FIXME("Somebody sent the shell a WM_QUIT message, should we reboot?");

            /* Sending the tray window a WM_QUIT message is actually a
             * tip given by some programming websites as a way of
             * forcing a reboot! let's delay implementing this hack
             * until we find a program that really needs it. for now
             * just bail out.
             */
            
            break;
        }

        TranslateMessage(&message);
        DispatchMessage(&message);
    }

    shutdown_systray();
    
    return 0;
}
